@@ -1,4 +1,4 @@
-#' @title jsRepeatedGadjet: Shiny Gadget of Repeated measure analysis.
+#' @title jsRepeatedGadget: Shiny Gadget of Repeated measure analysis.
 #' @description Shiny Gadget including Data, Label info, Table 1, GEE(linear, logistic), Basic plot
 #' @param data data
 #' @param nfactor.limit nlevels limit for categorical variables
@@ -6,9 +6,9 @@
 #' @details Shiny Gadget including Data, Label info, Table 1, GEE(linear, logistic), Basic plot
 #' @examples
 #' if (interactive()) {
-#'   jsRepeatedGadjet(mtcars)
+#'   jsRepeatedGadget(mtcars)
 #' }
-#' @rdname jsRepeatedGadjet
+#' @rdname jsRepeatedGadget
 #' @export
 #' @importFrom GGally ggpairs
 #' @importFrom stats as.formula binomial
@@ -20,7 +20,7 @@
 #' @import ggplot2
 #' @import shiny
 
-jsRepeatedGadjet <- function(data, nfactor.limit = 20) {
+jsRepeatedGadget <- function(data, nfactor.limit = 20) {
   requireNamespace("survival")
   # requireNamespace("survC1")
 
@@ -554,10 +554,10 @@ jsRepeatedGadjet <- function(data, nfactor.limit = 20) {
 
 
 
-#' @title jsRepeatedAddin: Rstudio addin of jsRepeatedGadjet
-#' @description Rstudio addin of jsRepeatedGadjet
-#' @return Rstudio addin of jsRepeatedGadjet
-#' @details Rstudio addin of jsRepeatedGadjet
+#' @title jsRepeatedAddin: Rstudio addin of jsRepeatedGadget
+#' @description Rstudio addin of jsRepeatedGadget
+#' @return Rstudio addin of jsRepeatedGadget
+#' @details Rstudio addin of jsRepeatedGadget
 #' @examples
 #' if (interactive()) {
 #'   jsRepeatedAddin()
@@ -575,7 +575,7 @@ jsRepeatedAddin <- function() {
   dataString <- context$selection[[1]]$text
   data <- get(dataString, envir = .GlobalEnv)
   # viewer <- dialogViewer("Subset", width = 1000, height = 800)
-  jsRepeatedGadjet(data, nfactor.limit = 20)
+  jsRepeatedGadget(data, nfactor.limit = 20)
 }
 
 
